export declare enum MarkupMode {
    markdown = 0,
    richedit = 1,
    text = 2,
}
export declare enum MarkupStyle {
    custom = "custom",
    plain = "plain",
    monokai = "monokai",
}
export interface MarkupOptions {
    content?: string;
    custom?: any;
    font?: string;
    fontSize?: number;
    mode: MarkupMode;
    styling: MarkupStyle;
}
export declare class Markup {
    private _modes;
    private _opts;
    private _pos;
    private _processor;
    private _quill;
    private _styles;
    constructor(quill: any, opts: MarkupOptions);
    /**
     * @return {number} the current position within the buffer
     */
    readonly pos: number;
    /**
     * Changes the current highlighting mode and display style.  It also sets
     * the content within control.
     * @param opts {HighlightOptions} configuration options.  `mode` sets the
     * editing mode.  `styling` sets the current display theme.  `custom` is
     * an object that contains custom format colors (for highlights).  The
     * `content` resets the content within the control.  If this is null it
     * is ignored.
     */
    set(opts: MarkupOptions): void;
    setBold(): void;
    setFont(fontName: string): void;
    setFontSize(fontSize: string): void;
    private handleEditorChange(eventName, ...args);
    private handleSelection(range, oldRange, source);
    private handleTextChange(delta, old, source);
}
